########
profiles
########

.. toctree::
   :maxdepth: 1

   opentype
   universal
   adobefonts
   googlefonts
   notofonts
   fontbureau
   fontwerk
   fontval
   ufo_sources
   iso15008
   layout
   outline
   shaping
   shared_conditions
   googlefonts_conditions


.. automodule:: fontbakery.profiles
   :members:
   :undoc-members:
